==> ejc-supbid-impl-3.0.1-20220124.080804-130-sources.jar: com/ejianc/business/supbid/purchase/bean/PurchaseSchemeRecordEntity.java <==
package com.ejianc.business.supbid.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.supbid.purchase.bean.PurchaseSchemeDetailRecordEntity;
/**
 * 设备采购洽商谈判方案记录表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_purchase_scheme_record")
public class PurchaseSchemeRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private Long noticeId; // 主表主键
    @TableField(value="source_id")
    private String sourceId; // 招标信息主键
    @TableField(value="scheme_name")
    private String schemeName; // 方案名称
    @TableField(value="money")
    private BigDecimal money; // 报价总额
    @TableField(value="money_tax")
    private BigDecimal moneyTax; // 报价总额(含税)
    @TableField(value="talk_num")
    private Integer talkNum; // 轮数
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="purchaseSchemeDetailRecordService",pidName = "schemeId")//此处有pid="xxx"，默认值pid="pid"
    private List<PurchaseSchemeDetailRecordEntity> purchaseSchemeDetailRecordList = new ArrayList<>(); // 设备采购洽商谈判方案明细记录表
    

    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    public Integer getTalkNum() {
        return talkNum;
    }

    public void setTalkNum(Integer talkNum) {
        this.talkNum = talkNum;
    }
    
    public List<PurchaseSchemeDetailRecordEntity> getPurchaseSchemeDetailRecordList() {
        return purchaseSchemeDetailRecordList;
    }

    public void setPurchaseSchemeDetailRecordList(List<PurchaseSchemeDetailRecordEntity> purchaseSchemeDetailRecordList) {
        this.purchaseSchemeDetailRecordList = purchaseSchemeDetailRecordList;
    }
}

==> ejc-supbid-impl-3.0.1-20231117.091130-245-sources.jar: com/ejianc/business/supbid/purchase/bean/PurchaseSchemeRecordEntity.java <==
package com.ejianc.business.supbid.purchase.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.supbid.purchase.bean.PurchaseSchemeDetailRecordEntity;
/**
 * 设备采购洽商谈判方案记录表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_purchase_scheme_record")
public class PurchaseSchemeRecordEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="notice_id")
    private Long noticeId; // 主表主键
    @TableField(value="source_id")
    private String sourceId; // 招标信息主键
    @TableField(value="scheme_name")
    private String schemeName; // 方案名称
    @TableField(value="money")
    private BigDecimal money; // 报价总额
    @TableField(value="money_tax")
    private BigDecimal moneyTax; // 报价总额(含税)
    @TableField(value="talk_num")
    private Integer talkNum; // 轮数
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="purchaseSchemeDetailRecordService",pidName = "schemeId")//此处有pid="xxx"，默认值pid="pid"
    private List<PurchaseSchemeDetailRecordEntity> purchaseSchemeDetailList = new ArrayList<>(); // 设备采购洽商谈判方案明细记录表
    

    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
    public String getSchemeName() {
        return schemeName;
    }

    public void setSchemeName(String schemeName) {
        this.schemeName = schemeName;
    }
    public BigDecimal getMoney() {
        return money;
    }

    public void setMoney(BigDecimal money) {
        this.money = money;
    }
    public BigDecimal getMoneyTax() {
        return moneyTax;
    }

    public void setMoneyTax(BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    public Integer getTalkNum() {
        return talkNum;
    }

    public void setTalkNum(Integer talkNum) {
        this.talkNum = talkNum;
    }

    public List<PurchaseSchemeDetailRecordEntity> getPurchaseSchemeDetailList() {
        return purchaseSchemeDetailList;
    }

    public void setPurchaseSchemeDetailList(List<PurchaseSchemeDetailRecordEntity> purchaseSchemeDetailList) {
        this.purchaseSchemeDetailList = purchaseSchemeDetailList;
    }
}
